pub struct TypesProposedContent {
pub kind: ProposedContentKind,
pub content: String,
pub structured: Option<Value>,
/* private fields */
}Expand description
Content of a proposal.
Fields
kind: ProposedContentKindWhat kind of content this is
content: StringThe textual content
structured: Option<Value>Structured content (if applicable)
Implementations
Sourceimpl ProposedContent
impl ProposedContent
Sourcepub fn new(
kind: ProposedContentKind,
content: impl Into<String>,
) -> ProposedContent
pub fn new( kind: ProposedContentKind, content: impl Into<String>, ) -> ProposedContent
Create new proposed content.
Sourcepub fn confidence(&self) -> Option<f32>
pub fn confidence(&self) -> Option<f32>
Returns the confidence score if set, always in [0.0, 1.0].
Sourcepub fn with_structured(self, structured: Value) -> ProposedContent
pub fn with_structured(self, structured: Value) -> ProposedContent
Add structured content.
Sourcepub fn with_confidence(self, confidence: f32) -> ProposedContent
pub fn with_confidence(self, confidence: f32) -> ProposedContent
Set a confidence baseline.
The value is clamped to [0.0, 1.0]. Non-finite values are treated as 0.0.
Use adjust_confidence to accumulate criteria on top.
Sourcepub fn adjust_confidence(self, delta: f32) -> ProposedContent
pub fn adjust_confidence(self, delta: f32) -> ProposedContent
Adjust confidence by a delta, clamped to [0.0, 1.0].
If no confidence has been set, the delta is applied from 0.0.